/***************************************************
* By CCSC compiler
*  File Name: 20141123_K375_MK324_1822.c
*  Description: check photo sensor voltage, and turn on buzzer
*  RA0 ADCIN, pot for delay timer
*  RA1 out, power for pot
*  RA2 INT, interrupt photo diode
*  RA3 IN, NA
*  RA4 OUT, option output, open collector
*  RA5 OUT, buzzer, PWM out
*  COPYRIGHT 2019 MYCOMKITS.COM, owned by CNET LIMITED
***************************************************/
//
#include <12f1822.h>
#DEVICE ADC=8
#fuses	INTRC_IO, NOWDT, NOMCLR, NOBROWNOUT, PUT, NOLVP, NOPROTECT, NODEBUG
#fuses	NOCPD, NOCLKOUT, NOWRT, NOIESO, NOFCMEN, PLL_SW, NOSTVREN
#use	delay(CLOCK = 4000000)
//
#use	fast_io(a)
//
#byte OSCCON = 0x099
#byte APFCON = 0x11D
//
#define Amode 0x0D  //port A all in, except A1, 4, 5
#define option PIN_A4
#define buzzer PIN_A5
#define photo PIN_A2
#define power_pot PIN_A1
// variables
int pot = 0;
int wakeup = 0;
int running = 0;
//
// prototyping
#separate
void initializing();
#separate
void get_pot();
// main function
void main()
{
    initializing();
    delay_ms(10000);    // wait 10 seconds to start
    // main loop
    while(1)
    {
        if(wakeup == 1)
        {
            if(running == 0)
            {
                int i=0;
                get_pot();	// get value from sensor and pot
                for(i=0; i<pot; i++) delay_ms(705);  // 0 to 3minutes(180000)
            }
            if(input(photo) == 1)
            {
                output_high(option);
                set_pwm1_duty(0x7F);    // duty 50%
                delay_ms(100);
                set_pwm1_duty(0);    // off
                delay_ms(50);
                running = 1;
            }
            else wakeup = 0;
        }
        else
        {
            set_pwm1_duty(0x0);    // buzzer off
            output_low(option);
            running = 0;
            sleep();
        }
    }
}
//
#separate
void initializing()
{
    set_tris_a(Amode);	//
    //
    setup_comparator(NC_NC);
    //setup_oscillator(OSC_4MHZ | OSC_PLL_OFF);
    // A/D converter initialize
    setup_adc_ports(sAN0| VSS_VDD);	// gnd to VCC, 3.3V
    setup_adc(ADC_CLOCK_DIV_8);	// 2usec
    //
    setup_ccp1(ccp_pwm);	//port RA5
    APFCON = APFCON | 0x01;	// set RA5 as PWM out, must set it after SETUP_CCP1
    setup_timer_2(T2_DIV_BY_1,0xFF,1);
    set_pwm1_duty(0x00);
    //
    output_low(option);	// open collector out off
    output_low(buzzer);	// buzzer off
    output_low(power_pot);	// pot power off
    //
    set_pwm1_duty(0x7F);    // duty 50%
    delay_ms(100);  // start signal
    set_pwm1_duty(0x0);    // buzzer off
    //
    enable_interrupts(INT_EXT);
    ext_int_edge(L_TO_H);
    enable_interrupts(GLOBAL);
}
//
#separate
void get_pot()
{
	// AN0 for pot
    output_high(power_pot);
    delay_ms(10);
	set_adc_channel(0);	//must wait 65u, AN0
	delay_us(100);
	pot = read_adc();	// 0 to 255, 0V to 3.3V
    output_low(power_pot);
}
//
#INT_EXT
void ext_isr(void)
{
    delay_ms(30);
    if(input(photo) == 1)   // cut off chattering
    {
        wakeup=1;
    }
}
